import axios from'axios';import {useLocation}from'react-router-dom';// export const API_URL = "http://localhost:44344";
// export const API_URL = process.env.NODE_ENV === "development" ? "http://localhost:3000" : "https://nicehostel.herokuapp.com";
const API_URL = "https://nicehostel.herokuapp.com";
const API_IMAGE_UPLOADER_URL = "https://api.imgur.com/3/upload";
// const API_IMAGE_CLIENT_SECRET = "5e497c2ba20ff36c20aa512366ddee25300c56e1";
const axAuth = axios.create();
const axImageUpload = axios.create();
axAuth.interceptors.request.use((config) => {
    const token = localStorage.getItem("token");
    config.headers.Authorization = `Bearer ${token}`;
    return config;
});
axAuth.interceptors.response.use((response) => {
    return response;
}, function (error) {
    // if (error.response.status === 401) {
    //     console.log('unauthorized');
    //     localStorage.removeItem("token");
    // }
    // if (error.response.status === 403){
    //     console.log("Forbidden");
    // }
    // else if(error.response.status === 404){
    //     return Promise.reject("Connection error")
    // }
    return Promise.reject(error.response);
});
const postReview = (data) => {
    return axAuth({
        url: API_URL + "/api/reviews/",
        method: "POST",
        data: data,
    });
};
const postRoom = (data) => {
    return axAuth({
        method: "POST",
        url: API_URL + "/api/properties/",
        data: data,
    });
};
const postImage = (data) => axImageUpload({
    method: "post",
    url: API_IMAGE_UPLOADER_URL,
    data: data,
    headers: {
        'Content-Type': 'multipart/form-data',
    },
});
const postReservation = (bookInfo) => axAuth({
    url: API_URL + "/api/reservations",
    method: "POST",
    data: JSON.stringify({
        "propertyId": bookInfo.roomId,
        "fromDate": bookInfo.bookFromDate,
        "toDate": bookInfo.bookToDate,
        "adultNum": bookInfo.guest,
        "childrenNum": bookInfo.children
    }),
    headers: {
        'Content-Type': "application/json"
    }
});
const deleteImage = (delHash) => axAuth({
    method: "DELETE",
    url: `https://api.imgur.com/3/image/${delHash}`,
});
const authenticate = (req) => {
    return axAuth.post(API_URL + "/api/user/authenticate", {
        "email": req.email,
        "password": req.password
    });
};
const registerHost = () => axAuth.post(API_URL + "/api/user/register-host");
const register = (req) => {
    return axios.post(API_URL + "/api/user/register-user", {
        "email": req.email,
        "password": req.password,
        "confirmPassword": req.confirmPassword
    });
};
const fetchPropertiesView = async (typeId, query) => {
    let URI = `/api/properties`;
    console.log(query);
    return axios.get(API_URL + URI, {
        params: {
            typeId: typeId,
            city: query.city,
            from: query.from,
            to: query.to,
            guestNum: query.guestNum,
            childrenNum: query.childrenNum,
        }
    });
};
const fetchCities = async () => {
    // const res = await ax({
    //     method: "GET",
    //     url: URL + "api/city",
    //     timeout: 5000
    // });
    // return res;
    const res = await fetch(API_URL + "/api/cities");
    const data = res.json();
    return data;
};
const fetchPropertyTypes = async () => {
    const res = await fetch(API_URL + "/api/propertytypes");
    const data = await res.json();
    return data;
};
const fetchPropertyById = async (id) => {
    return axAuth.get(API_URL + "/api/properties/" + id);
};
const fetchPropertiesSaved = () => {
    return axAuth.get(API_URL + "/api/properties/saved");
};
const fetchOwnerProperty = async () => axAuth.get(API_URL + "/api/properties/host");
const fetchUserReservation = async () => {
    return axAuth.get(API_URL + "/api/reservations/user");
};
const fetchPricing = (bookInfo) => {
    console.log(bookInfo);
    return axios.get(API_URL + "/api/reservations/check-pricing", {
        params: {
            fromDate: bookInfo.bookFromDate,
            toDate: bookInfo.bookToDate,
            propertyId: bookInfo.roomId,
            guestNum: bookInfo.guest,
            childrenNum: bookInfo.children
        }
    });
};
const fetchReviewsForProperty = async (propId) => {
    return axAuth.get(API_URL + `/api/reviews`, {
        params: {
            propertyId: propId,
        }
    });
};
const fetchServices = async () => axAuth.get(API_URL + "/api/properties/services");
const deleteReservation = async (resId) => {
    return axAuth.delete(API_URL + "/api/reservations/" + resId);
};
const useQueryParam = () => {
    return new URLSearchParams(useLocation().search);
};
const toggleLike = ({ roomId, token }) => {
    return axAuth.post(`${API_URL}/api/likes/${roomId}`, {}, {
        headers: {
            Authorization: `Bearer ${token}`
        }
    });
};
const validateToken = (token) => {
    return fetch(`${API_URL}/api/user/validate-token`, {
        headers: {
            Authorization: `Bearer ${token}`
        }
    });
};export{API_URL,authenticate,axAuth,axImageUpload,deleteImage,deleteReservation,fetchCities,fetchOwnerProperty,fetchPricing,fetchPropertiesSaved,fetchPropertiesView,fetchPropertyById,fetchPropertyTypes,fetchReviewsForProperty,fetchServices,fetchUserReservation,postImage,postReservation,postReview,postRoom,register,registerHost,toggleLike,useQueryParam,validateToken};//# sourceMappingURL=API.js.map
