import {useDisclosure,useToast,Box,Flex,Spacer,Popover,PopoverTrigger,HStack,Button,PopoverContent,Collapse,Tooltip,Spinner,Divider}from'@chakra-ui/react';import React__default from'react';import {BsStarFill,BsStar}from'react-icons/bs';import {useQuery,useMutation}from'react-query';import {useHistory}from'react-router';import {fetchPricing,postReservation}from'../API.js';import {AuthContext}from'../Contexts/AuthContext.js';import PickRangeDay,{getDatesBetween}from'./NavComponents/PickRangeDay.js';import PopDetail from'./NavComponents/PopDetail.js';const FloatingForm = ({ room, bookInfo, updateDate, updatePeople }) => {
    var _a, _b, _c, _d, _e;
    const auth = React__default.useContext(AuthContext);
    const history = useHistory();
    const feeCollapse = useDisclosure();
    const [nightCount, setNightCount] = React__default.useState(0);
    const toast = useToast();
    const checkPricing = useQuery(["pricing", bookInfo], () => {
        if (bookInfo.roomId && bookInfo.bookFromDate && bookInfo.bookToDate) {
            return fetchPricing(bookInfo);
        }
    }, {
        onSuccess: (data) => console.log(data === null || data === void 0 ? void 0 : data.data),
        staleTime: 1000 * 60
    });
    const reservMutation = useMutation(postReservation, {
        onSuccess: (data) => {
            toast({ description: "Success", status: "success", isClosable: true });
            history.push("/profile?view=reservations");
        },
        onError: (err) => {
            toast({ description: "Something's wrong", status: "error", isClosable: true });
        }
    });
    const handleCheckout = async () => {
        if (!auth.user)
            return toast({
                description: "Login is required",
                status: "info",
                isClosable: true
            });
        reservMutation.mutate(bookInfo);
    };
    let price = (_a = checkPricing.data) === null || _a === void 0 ? void 0 : _a.data;
    React__default.useEffect(() => {
        if (bookInfo.bookFromDate && bookInfo.bookToDate) {
            setNightCount(getDatesBetween(bookInfo.bookFromDate.toDateString(), bookInfo.bookToDate.toDateString()).length + 1);
            return feeCollapse.onOpen();
        }
        return feeCollapse.onClose();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [bookInfo.bookFromDate, bookInfo.bookToDate]);
    return (React__default.createElement(Box, { display: "inline-flex", flexDir: "column", alignContent: "center", justifyContent: "center" },
        React__default.createElement(Flex, { alignItems: "baseline" },
            React__default.createElement(Box, { as: "h2", fontFamily: "mono", fontSize: "3xl", fontWeight: "semibold" }, room.formattedPrice + "$ "),
            React__default.createElement(Box, { as: "span", color: "gray.500", fontStyle: "italic" }, "/ per night"),
            React__default.createElement(Spacer, null),
            React__default.createElement(Box, { d: "flex", alignItems: "center" }, Array(5).fill("").map((_, i) => {
                return (i < Math.round(room.totalStar / room.totalReview) ? React__default.createElement(BsStarFill, { key: i, colorRendering: "teal.400" }) : React__default.createElement(BsStar, { key: i }));
            }))),
        React__default.createElement(Box, { mt: "4" },
            React__default.createElement(Popover, { closeOnBlur: true },
                React__default.createElement(PopoverTrigger, null,
                    React__default.createElement(HStack, { spacing: "0" },
                        React__default.createElement(Button, { variant: "outline", borderTopLeftRadius: "lg", size: "lg", w: "100%", _focusVisible: { border: "0" }, borderRadius: "0" }, ((_b = bookInfo === null || bookInfo === void 0 ? void 0 : bookInfo.bookFromDate) === null || _b === void 0 ? void 0 : _b.toLocaleDateString()) || "From"),
                        React__default.createElement(Button, { variant: "outline", borderTopRightRadius: "lg", size: "lg", w: "100%", _focusVisible: { border: "0" }, borderRadius: "0" }, ((_c = bookInfo === null || bookInfo === void 0 ? void 0 : bookInfo.bookToDate) === null || _c === void 0 ? void 0 : _c.toLocaleDateString()) || "To"))),
                React__default.createElement(PopoverContent, { flexWrap: "nowrap", alignItems: "center", w: { base: "100%", lg: "550px" }, style: { backdropFilter: "blur(5px)" }, borderRadius: "0", bg: "inherit", bgColor: "rgba(66, 153, 225, 0.5)" },
                    React__default.createElement(PickRangeDay, { schedules: { reservedDates: room.reservedDates, dayOff: room.daysOff }, updateDate: updateDate }))),
            React__default.createElement(Popover, null,
                React__default.createElement(PopoverTrigger, null,
                    React__default.createElement(Button, { variant: "outline", w: "100%", size: "lg", borderRadius: "0", borderBottomRadius: "lg", px: "2" }, bookInfo.guest + ' guests - ' + bookInfo.children + ' children')),
                React__default.createElement(PopoverContent, { flexWrap: "nowrap", borderRadius: "0", bg: "inherit", bgColor: "rgba(66, 153, 225, 0.5)" },
                    React__default.createElement(PopDetail, { updatePeople: updatePeople, guest: bookInfo.guest, children: bookInfo.children, maxGuest: room.maxGuest })))),
        React__default.createElement(Button, { variant: "solid", colorScheme: "green", alignSelf: "stretch", mt: "4", isDisabled: !feeCollapse.isOpen || room.ownerInfo.userId === ((_d = auth.user) === null || _d === void 0 ? void 0 : _d.userId), onClick: handleCheckout }, room.ownerInfo.userId === ((_e = auth.user) === null || _e === void 0 ? void 0 : _e.userId) ? "You can't book your own property" :
            !feeCollapse.isOpen ? "Choose dates to see detail" : "Proceed checkout"),
        React__default.createElement(Box, { alignSelf: "center", my: "2", fontWeight: "thin", fontStyle: "oblique" }, "You won't be charged yet"),
        React__default.createElement(Collapse, { in: feeCollapse.isOpen },
            React__default.createElement(Box, { fontSize: "lg" },
                React__default.createElement(Flex, { alignItems: "baseline" },
                    React__default.createElement(Tooltip, { label: nightCount && `You are currently booking ${price === null || price === void 0 ? void 0 : price.nightCount} night(s)`, placement: "left", hasArrow: true },
                        React__default.createElement(Box, { fontWeight: "light", textDecoration: "underline" },
                            room.formattedPrice,
                            "$ x ", price === null || price === void 0 ? void 0 :
                            price.nightCount,
                            " nights")),
                    React__default.createElement(Spacer, null),
                    checkPricing.isLoading ? React__default.createElement(Spinner, null) :
                        React__default.createElement(Box, { fontFamily: "mono" }, price && `${(price === null || price === void 0 ? void 0 : price.pricePerNight) * (price === null || price === void 0 ? void 0 : price.nightCount)} $`)),
                React__default.createElement(Flex, { alignItems: "baseline" },
                    React__default.createElement(Tooltip, { label: "The owner keeps your place in highest cleanliness", placement: "left", hasArrow: true },
                        React__default.createElement(Box, { fontWeight: "light", textDecoration: "underline" }, "Cleaning fee")),
                    React__default.createElement(Spacer, null),
                    checkPricing.isLoading ? React__default.createElement(Spinner, null) :
                        React__default.createElement(Box, { fontFamily: "mono" }, price === null || price === void 0 ? void 0 :
                            price.cleaningFee,
                            " $")),
                React__default.createElement(Flex, { alignItems: "baseline" },
                    React__default.createElement(Tooltip, { label: "This helps us run our platform and offer services like 24/7 support on your trip. It includes VAT.", placement: "left", hasArrow: true },
                        React__default.createElement(Box, { fontWeight: "light", textDecoration: "underline" }, "Service fee")),
                    React__default.createElement(Spacer, null),
                    checkPricing.isLoading ? React__default.createElement(Spinner, null) :
                        React__default.createElement(Box, { fontFamily: "mono" }, price === null || price === void 0 ? void 0 :
                            price.serviceFee,
                            " $")),
                React__default.createElement(Flex, { alignItems: "baseline" },
                    React__default.createElement(Tooltip, { label: "We offer you discount based on your reservation!", placement: "left", hasArrow: true },
                        React__default.createElement(Box, { fontWeight: "light", textDecoration: "underline" },
                            "Discount",
                            React__default.createElement(Box, { as: "span", textDecoration: "none", mx: "2" }, price ? price.discountPercent + "%" : "0%"))),
                    React__default.createElement(Spacer, null),
                    checkPricing.isLoading ? React__default.createElement(Spinner, null) :
                        React__default.createElement(Box, { fontFamily: "mono" }, price === null || price === void 0 ? void 0 :
                            price.discount,
                            " $")),
                React__default.createElement(Divider, { my: "2", colorScheme: "green", variant: "dashed" }),
                React__default.createElement(Flex, { fontWeight: "black", fontSize: "3xl" },
                    React__default.createElement(Box, { fontFamily: "mono" }, "Total"),
                    React__default.createElement(Spacer, null),
                    checkPricing.isLoading ? React__default.createElement(Spinner, null) :
                        React__default.createElement(Box, { fontFamily: "mono" }, price === null || price === void 0 ? void 0 :
                            price.totalCost,
                            " $"))))));
};export default FloatingForm;//# sourceMappingURL=FloatingForm.js.map
